<?php

/****************************************************************************************
* LiveZilla objects.global.users.inc.php
* 
* Copyright 2001-2008 SPAUN Power GmbH
* All rights reserved.
* LiveZilla is a registered trademark.
* 
* Improper changes in this file may cause critical errors. It is strongly 
* recommended to desist from editing this file.
* 
***************************************************************************************/ 

if(!defined("IN_LIVEZILLA"))
	die();
	
require("./_lib/objects.global.inc.php");
class User
{
	var $IP;
	var $SessId;
	var $UserId;
	var $SystemId;
	var $Messages = Array();
	var $Status = USER_STATUS_OFFLINE;
	var $Type;
	var $Folder;
	var $FolderInbox;
	var $FolderSent;
	var $SessionFile;
	var $FirstActive;
	var $LastActive;
	var $Fullname;
	var $Company;
	var $Email;
	var $Typing = false;
	var $FileError;
	var $Comparer;
	
	function User($_userid)
   	{
		$this->UserId = $_userid;
   	}
	
	function GetPosts()
	{
		$messageFileCount = 0;
		$posts = Array();
		$messageFiles = getDirectory($this->FolderInbox,false);
		sort($messageFiles);
		foreach($messageFiles as $index => $file)
		{
			if(strpos($file,"_") !== false && strpos($file,EX_MESSAGE) !== false)
			{
				$parts = explode("_",str_replace("." . EX_MESSAGE,"",$file));
				$fileEditor = new FileEditor($this->FolderInbox . $file);
				$fileEditor->Load();
				if(count($fileEditor->Errors) == 0 && is_array($fileEditor->Result))
				{	
					foreach($fileEditor->Result as $post)
					{
						if(!isset($posts[$parts[1]]))
							$posts[$parts[1]] = Array();
							
						array_push($posts[$parts[1]],new Post("","",$post["s_receiver"],$post["s_text"],$post["s_title"],$post["s_special"],@filemtime($this->FolderInbox . $file)));
					}
					@unlink($this->FolderInbox . $file);
				}
			}
			if(++$messageFileCount >= 10)
				break;
		}
		return $posts;
	}
	
	function AppendFromCookies()
	{
		if(getCookieValue("login_email") != null)
			$this->Email = (getCookieValue("login_email"));

		if(getCookieValue("login_name") != null)
			$this->Fullname = (getCookieValue("login_name"));

		if(getCookieValue("login_company") != null)
			$this->Company = (getCookieValue("login_company"));
	}
	
	function Save()
	{
		if(!@is_dir($this->Folder))
			createFolder($this->Folder);
			
		$fileEditor = new FileEditor($this->SessionFile);
		$fileEditor->Save($this->GetData());
		
		if(count($fileEditor->Errors) > 0)
			$this->FileError = $fileEditor->Errors;
	}
	
	function KeepAlive()
	{
		if(file_exists($this->SessionFile))
			@touch($this->SessionFile);
		else
			$this->Save();
	}
	
	function Destroy()
	{
		if(file_exists($this->SessionFile))
			@unlink($this->SessionFile);
	}
}

class UserInternal extends User
{
	var $Level = 0;
	var $Webspace = 0;
	var $LoginId;
	var $Password;
	var $Description;
	var $WebcamFile;
	var $PictureFile;
	var $VisitcardFile;
	var $ServerSetup = false;
	var $Authenticated = false;
	var $VisitorFileSizes;
	var $VisitorStaticReload;
	var $ExternalChats;
	var $PermissionSet;
	var $Groups;
	var $GroupsArray;

	function UserInternal($_sessid,$_userid)
   	{
		$this->SessId = $this->SystemId = $_sessid;
		$this->UserId = $_userid;
		$this->ExternalChats = Array();
		$this->Folder = PATH_DATA_INTERNAL . $this->SessId . "/";
		$this->FolderInbox = $this->Folder . "_inbox/";
		$this->FolderSent = $this->Folder . "_sent/";
		
		if(!@is_dir($this->FolderInbox))
			createFolder($this->FolderInbox);
			
		if(!@is_dir($this->FolderSent))
			createFolder($this->FolderSent);

		$this->WebcamFile = PATH_INTERN_IMAGES . base64_encode($this->UserId) . FILE_EXTENSION_WEBCAM_PICTURE;
		$this->PictureFile = PATH_INTERN_IMAGES . base64_encode($this->UserId) . FILE_EXTENSION_PROFILE_PICTURE;
		$this->VisitcardFile = PATH_VISITCARDS . $this->UserId . FILE_EXTENSION_VISITCARD;
		$this->PasswordFile = PATH_USERS . $this->SessId . FILE_EXTENSION_PASSWORD;
		$this->ChangePasswordFile = PATH_USERS . $this->SessId . FILE_EXTENSION_CHANGE_PASSWORD;
		$this->Type = USER_TYPE_INTERN;
		$this->SessionFile = $this->Folder . $this->SessId . "." . EX_INTERN_SESSION;
		$this->VisitorFileSizes = Array();
		$this->VisitorStaticReload = Array();
   	}
	
	function Load()
	{
		$this->FileError = null;
		$fileEditor = new FileEditor($this->SessionFile);
		$fileEditor->Load();
		if(count($fileEditor->Errors) == 0)
		{
			$this->LoginId = $fileEditor->Result["s_login_id"];
			$this->FirstActive = $fileEditor->Result["s_first_active"];
			$this->LastActive = @filemtime($this->SessionFile);
			$this->Password = $fileEditor->Result["s_password"];
			$this->Status = $fileEditor->Result["s_status"];
			$this->Level = $fileEditor->Result["s_level"];
			$this->IP = $fileEditor->Result["s_ip"];
			$this->Typing = $fileEditor->Result["s_typing"];
			$this->VisitorFileSizes = $fileEditor->Result["s_vi_file_sizes"];
		}
		else
			$this->FileError = $fileEditor->Errors;
	}
	
	function IsExternal($_groupList)
	{
		foreach($this->Groups as $groupid)
			if($_groupList[$groupid]["gr_extern"])
				return true;
		return false;
	}
	
	function GetData()
	{
		$data = Array();
		$data["s_login_id"] = $this->LoginId;
		$data["s_first_active"] = $this->FirstActive;
		$data["s_password"] = $this->Password;
		$data["s_status"] = $this->Status;
		$data["s_level"] = $this->Level;
		$data["s_ip"] = $this->IP;
		$data["s_typing"] = $this->Typing;
		$data["s_vi_file_sizes"] = $this->VisitorFileSizes;
		return $data;
	}
	
	function CreateComparer()
	{
		$this->Comparer = new UserInternal($this->SessId,$this->UserId);
		$this->Comparer->LoginId = $this->LoginId;
		$this->Comparer->FirstActive = $this->FirstActive;
		$this->Comparer->LastActive = $this->LastActive;
		$this->Comparer->Password = $this->Password;
		$this->Comparer->Status = $this->Status;
		$this->Comparer->Level = $this->Level;
		$this->Comparer->IP = $this->IP;
		$this->Comparer->Typing = $this->Typing;
		$this->Comparer->VisitorFileSizes = $this->VisitorFileSizes;
	}
	
	function EcoSave($difference = false)
	{
		if($this->Comparer->LoginId != $this->LoginId)$difference = true;
		else if($this->Comparer->FirstActive != $this->FirstActive)$difference = true;
		else if($this->Comparer->LastActive != $this->LastActive)$difference = true;
		else if($this->Comparer->Password != $this->Password)$difference = true;
		else if($this->Comparer->Status != $this->Status)$difference = true;
		else if($this->Comparer->Level != $this->Level)$difference = true;
		else if($this->Comparer->IP != $this->IP)$difference = true;
		else if($this->Comparer->Typing != $this->Typing)$difference = true;
		else if($this->Comparer->VisitorFileSizes != $this->VisitorFileSizes)$difference = true;
		
		if($difference)
			$this->Save();
		else
			$this->KeepAlive();
	}
	
	function GetExternalObjects()
	{
		$actionfiles = getDirectory($this->Folder,false);
		sort($actionfiles);
		foreach($actionfiles as $index => $file)
		{
			if(strpos($file, "." . EX_CHAT_OPEN) !== false)
			{
				$chat = new Chat(null,null);
				$chat->Load($this->Folder . $file);
				$this->ExternalChats[$chat->ExternalUser->SystemId] = $chat;
			}
			else if(strpos($file, "." . EX_FILE_UPLOAD_REQUEST) !== false)
			{
				$request = new FileUploadRequest(str_replace(".".EX_FILE_UPLOAD_REQUEST,"",$file),$this->SessId);
				$request->Load();
				
				if(isset($chat) && isset($this->ExternalChats[$chat->ExternalUser->SystemId]))
				{
					if($this->ExternalChats[$chat->ExternalUser->SystemId]->Activated != CHAT_STATUS_ACTIVE)
					{
						$request->Destroy();
					}
					else
					{
						if($request->Error)
						{
							$request->Destroy();
						}
						else if(file_exists($request->GetFile()) && @filemtime($request->GetFile()) > @filemtime($request->TargetFile))
						{
							$request->Download = true;
							$request->Destroy();
						}
						$this->ExternalChats[$chat->ExternalUser->SystemId]->FileUploadRequest = $request;
					}
				}
				else
				{
					$request->Destroy();
				}
			}
		}
	}
	
	function GetExternalChatAmount($amount=0)
	{
		$actionfiles = getDirectory($this->Folder,false);
		foreach($actionfiles as $index => $file)
		{
			if(strpos($file, "." . EX_CHAT_OPEN) !== false)
				$amount++;
		}
		return $amount;
	}
	
	function SetStaticCaller()
	{
		define("CALLER_SYSTEM_ID",$this->SystemId);
	}
	
	function LoadPassword()
	{
		$this->Password = null;
		if(file_exists($this->PasswordFile))
		{
			$data = getFile($this->PasswordFile);
			$this->Password = $data;
		}
		return $this->Password;
	}
	
	function ChangePassword($_password)
	{
		createFile($this->PasswordFile,md5($_password),true);
		if(file_exists($this->ChangePasswordFile))
			@unlink($this->ChangePasswordFile);
	}
	
	function IsPasswordChangeNeeded()
	{
		return file_exists($this->ChangePasswordFile);
	}
	
	function SetPasswordChangeNeeded($_needed)
	{
		if($_needed)
			createFile($this->ChangePasswordFile,"",false);
		else if(file_exists($this->ChangePasswordFile))
			@unlink($this->ChangePasswordFile);
	}
	
	function GetPermission($_type)
	{
		if($_type == PERMISSION_MESSAGES)
			return substr($this->PermissionSet,0,1);
		else if($_type == PERMISSION_RATINGS)
			return substr($this->PermissionSet,1,1);
	}

	function GetLoginReply($_extern,$_time)
	{
		return "<login>\r\n<login_return group=\"".base64_encode($this->GroupsArray)."\" name=\"".base64_encode($this->Fullname)."\" loginid=\"".base64_encode($this->LoginId)."\" level=\"".base64_encode($this->Level)."\" sess=\"".base64_encode($this->SystemId)."\" extern=\"".base64_encode($_extern)."\" timediff=\"".base64_encode($_time)."\" perms=\"".base64_encode($this->PermissionSet)."\" /></login>";
	}
}

class UserExternal extends User
{
	var $Browsers;
	var $ExternalStatic;
	var $Response;
	var $IsChat = false;
	var $ActiveChatRequest;
	
	function UserExternal($_userid)
   	{
		$this->Browsers = Array();
		$this->UserId = $_userid;
		$this->Folder = PATH_DATA_EXTERNAL . $this->UserId . "/";
   	}
	
	function SaveMail($_group)
	{
		$mail = new UserTicket($_SERVER["REMOTE_ADDR"] . "_" . time() . "." . EX_MAIL);
		$mail->IP = $_SERVER["REMOTE_ADDR"];
		
		setCookieValue("login_name",AJAXDecode($_POST[POST_EXTERN_USER_NAME]));
		setCookieValue("login_email",AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]));
		setCookieValue("login_company",AJAXDecode($_POST[POST_EXTERN_USER_COMPANY]));

		if(!$mail->IsFlood())
		{
			$mail->Fullname = AJAXDecode($_POST[POST_EXTERN_USER_NAME]);
			$mail->UserId = $_POST[POST_EXTERN_USER_USERID];
			$mail->Email = AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]);
			$mail->Group = $_group;
			$mail->Company = AJAXDecode($_POST[POST_EXTERN_USER_COMPANY]);
			$mail->Text = AJAXDecode($_POST[POST_EXTERN_USER_MAIL]);
			$mail->Save();
			$this->AddFunctionCall("lz_chat_mail_callback(true);",false);
			
			if(!file_exists(FILE_ANS_MESSAGES))
				createFile(FILE_ANS_MESSAGES,null,false);
			else
				@touch(FILE_ANS_MESSAGES);
			return true;
		}
		else
			$this->AddFunctionCall("lz_chat_mail_callback(false);",false);
		return false;
	}
	
	function SendCopyOfMail($_group,$_config,$_groups)
	{
		$message = "New Offline Message\r\nDate: " . date("r") . "\r\n-----------------------------------------------------\r\nName: " . AJAXDecode($_POST[POST_EXTERN_USER_NAME]) . "\r\nEmail: " . AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]) . "\r\nCompany: " . AJAXDecode($_POST[POST_EXTERN_USER_COMPANY]) ."\r\n-----------------------------------------------------\n\n";
		$message .= AJAXDecode($_POST[POST_EXTERN_USER_MAIL]);
		$sender = ($_config["gl_usmasend"] != null && isValidEmail(AJAXDecode($_POST[POST_EXTERN_USER_EMAIL])) && $_config["gl_smtpauth"] == null) ? AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]) : $_config["gl_mail_sender"];
		
		if($_config["gl_scom"] != null)
			sendMail($_config["gl_scom"],$sender,AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]),$message,$_config["gl_site_name"] . " - New Offline Message from " . AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]));
		if($_config["gl_sgom"] != null)
			sendMail($_groups[$_group]["gr_email"],$sender,AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]),$message,$_config["gl_site_name"] . " - New Offline Message from " . AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]));
	}
	
	function StoreFile($_browserId,$_partner)
	{
		$filename = namebase($_FILES['userfile']['name']);
		if(!isValidUploadFile($filename))
			return false;
	
		$folder = PATH_DATA_EXTERNAL . $this->UserId . "/browsers/" . $_browserId . "/uploads/";
		$uploadfile = $folder . base64_encode($filename);
		if(strpos($uploadfile,"..") === false)
		{
			$file = $_browserId."_".substr(md5($filename),0,5);
			if(!@is_dir($folder))
				createFolder($folder);
		
			$permission = new Permission("FileUploadPermission",$this->UserId,$_browserId,$file);
			if(file_exists($permission->TargetFile))
			{
				$permission->Load();
				$permission->Destroy();
				$request = new FileUploadRequest($file,$_partner);
				if($permission->Result == PERMISSION_FULL)
				{	
					if(@move_uploaded_file($_FILES['userfile']['tmp_name'], $uploadfile))
						return true;
				}
			}
		}
		return false;
	}
	
	function SaveRate($_internalName)
	{
		$rate = new Rating(bigTime() . "_" . $_SERVER["REMOTE_ADDR"],$_SERVER["REMOTE_ADDR"]);
		if(!$rate->IsFlood())
		{
			$rate->RateComment = AJAXDecode($_POST[POST_EXTERN_RATE_COMMENT]);
			$rate->RatePoliteness = $_POST[POST_EXTERN_RATE_POLITENESS];
			$rate->RateQualification = $_POST[POST_EXTERN_RATE_QUALIFICATION];
			$rate->Fullname = AJAXDecode($_POST[POST_EXTERN_USER_NAME]);
			$rate->Email = AJAXDecode($_POST[POST_EXTERN_USER_EMAIL]);
			$rate->Company = AJAXDecode($_POST[POST_EXTERN_USER_COMPANY]);
			$rate->UserId = $_POST[POST_EXTERN_USER_USERID];
			$rate->InternId = $_internalName;
			$rate->Save();
			
			if(!file_exists(FILE_ANS_RATINGS))
				createFile(FILE_ANS_RATINGS,null,false);
			else
				@touch(FILE_ANS_RATINGS);
				
			$this->AddFunctionCall("lz_chat_send_rate_callback(true);",false);
		}
		else
			$this->AddFunctionCall("lz_chat_send_rate_callback(false);",false);
	}
	
	function AddFunctionCall($_call,$_overwrite)
	{
		if($this->Response == null)
			$this->Response = "";
		if($_overwrite)
			$this->Response = $_call;
		else
			$this->Response .= $_call;
	}
	
	function LoadStaticInformation()
	{
		$this->ExternalStatic = new ExternalStatic($this->UserId);
	}
}

class ExternalBrowser extends User
{
	var $BrowserId;
	var $Referrer;
	var $History;
	var $Request;
	var $Guide;
	var $Alerts;
	var $Type = BROWSER_TYPE_BROWSER;
	
	function ExternalBrowser($_browserid,$_userid)
   	{
		$this->BrowserId = $_browserid;
		$this->UserId = $_userid;
		$this->SystemId = $this->UserId . "~" . $this->BrowserId;
		$this->Folder = PATH_DATA_EXTERNAL . $this->UserId . "/browsers/" . $this->BrowserId . "/";
		$this->SessionFile = $this->Folder . $this->BrowserId . "." . EX_BROWSER_SESSION;
		$this->AppendFromCookies();
   	}
	
	function Load()
	{
		$fileEditor = new FileEditor($this->SessionFile);
		$fileEditor->Load();
		if(count($fileEditor->Errors) == 0)
		{
			$this->FirstActive = $fileEditor->Result["s_first_active"];
			$this->History = $fileEditor->Result["s_history"];
			$this->Referrer = $fileEditor->Result["s_referrer"];
			
			if(isset($fileEditor->Result["s_fullname"]))
				$this->Fullname = $fileEditor->Result["s_fullname"];
				
			if(isset($fileEditor->Result["s_email"]))
				$this->Email = $fileEditor->Result["s_email"];
			
			if(isset($fileEditor->Result["s_company"]))
				$this->Company = $fileEditor->Result["s_company"];
		}
		else
			$this->FileError = $fileEditor->Errors;
		$this->AppendFromCookies();
	}

	function GetActions()
	{
		$actionfiles = getDirectory($this->Folder,false);
		$this->Request = null;
		$this->Guide = null;
		foreach($actionfiles as $key => $actionfile)
		{
			if(strpos($actionfile, "." . EX_CHAT_REQUEST) !== false || strpos($actionfile, "." . EX_CHAT_REQUEST_ACCEPTED) !== false || strpos($actionfile, "." . EX_CHAT_REQUEST_DECLINED) !== false)
			{
				if($this->Request == null)
				{
					if(strpos($actionfile, "." . EX_CHAT_REQUEST) !== false)
						$this->Request = new ChatRequest(str_replace("." . EX_CHAT_REQUEST,"",$actionfile),$this->UserId,$this->BrowserId,REQUEST_STATUS_ACTIVE);
					if(strpos($actionfile, "." . EX_CHAT_REQUEST_ACCEPTED) !== false)
						$this->Request = new ChatRequest(str_replace("." . EX_CHAT_REQUEST_ACCEPTED,"",$actionfile),$this->UserId,$this->BrowserId,REQUEST_STATUS_ACCEPTED);
					if(strpos($actionfile, "." . EX_CHAT_REQUEST_DECLINED) !== false)
						$this->Request = new ChatRequest(str_replace("." . EX_CHAT_REQUEST_DECLINED,"",$actionfile),$this->UserId,$this->BrowserId,REQUEST_STATUS_DECLINED);
					$this->Request->Load();
				}
				else
					unlink($this->Folder . $actionfile);
			}
			else if(strpos($actionfile, "." . EX_BROWSER_GUIDE) !== false)
			{
				if($this->Guide == null || ($this->Guide != null && @filemtime($this->Folder . $actionfile) > $this->Guide->Created))
				{
					$this->Guide = new Guide(str_replace("." . EX_BROWSER_GUIDE,"",$actionfile),$this->UserId,$this->BrowserId,true);
					$this->Guide->Created = @filemtime($this->Folder . $actionfile);
					$this->Guide->Load();
				}
				else
					unlink($this->Folder . $actionfile);
			}
			else if(strpos($actionfile, "." . EX_ALERT) !== false)
			{
				$this->Alerts[$key] = new Alert(str_replace("." . EX_ALERT,"",$actionfile),$this->UserId,$this->BrowserId);
				$this->Alerts[$key]->Load();
			}
		}
	}
	
	function GetData()
	{
		$data = Array();
		$data["s_first_active"] = $this->FirstActive;
		$data["s_history"] = $this->History;
		$data["s_referrer"] = $this->Referrer;
		if(!isnull($this->Fullname))
			$data["s_fullname"] = $this->Fullname;
			
		if(!isnull($this->Email))
			$data["s_email"] = $this->Email;
		
		if(!isnull($this->Company))
			$data["s_company"] = $this->Company;
		
		return $data;
	}
	
	function Destroy()
	{
		deleteDirectory($this->Folder);
	}
}

class ExternalChat extends ExternalBrowser
{
	var $DesiredChatGroup;
	var $DesiredChatPartner;
	var $DesiredChatPartnerTyping = false;
	var $Forward;
	var $Waiting;
	var $Chat;
	var $Code = "CHAT";
	var $Type = BROWSER_TYPE_CHAT;
	var $WaitingMessageDisplayed = null;
	var $NoEco = false;

	function ExternalChat($_userid,$_browserId)
   	{
		$this->UserId = $_userid;
		$this->BrowserId = $_browserId;
		$this->SystemId = $this->UserId . "~" . $this->BrowserId;
		$this->Folder = PATH_DATA_EXTERNAL . $this->UserId . "/browsers/" . $this->BrowserId . "/";
		$this->FolderInbox = $this->Folder . "_inbox/";
		$this->FolderSent = $this->Folder . "_sent/";
		$this->SessionFile = $this->Folder . $this->BrowserId . "." . EX_CHAT_SESSION;
		$this->AppendFromCookies();
		
		if(!@is_dir($this->FolderInbox))
			createFolder($this->FolderInbox);
			
		if(!@is_dir($this->FolderSent))
			createFolder($this->FolderSent);
   	}
	
	function GetData()
	{
		$data = Array();
		$data["s_typing"] = $this->Typing;
		
		if(!isnull($this->Fullname))
			$data["s_fullname"] = $this->Fullname;
		$data["s_email"] = $this->Email;
		$data["s_company"] = $this->Company;
		$data["s_waiting"] = $this->Waiting;
		$data["s_code"] = $this->Code;
		$data["s_first_active"] = ($this->FirstActive != null) ? $this->FirstActive : time();
		$data["s_internal"] = $this->DesiredChatPartner;
		$data["s_group"] = $this->DesiredChatGroup;
		$data["s_waiting_message"] = $this->WaitingMessageDisplayed;
		return $data;
	}
	
	function SetCookieGroup()
	{
		setCookieValue("login_group",$this->DesiredChatGroup);
	}
	
	function RequestFileUpload($_user,$_filename)
	{
		$fileid = substr(md5(namebase($_filename)),0,5);
		$request = new FileUploadRequest($this->BrowserId . "_" . $fileid,$this->DesiredChatPartner);
		$request->SenderUserId = $this->UserId;
		$request->Text = namebase($_filename);
		$request->SenderBrowserId = $this->BrowserId;
		$permission = new Permission("FileUploadPermission",$this->UserId,$this->BrowserId,$this->BrowserId."_".$fileid);
		if(file_exists($permission->TargetFile))
		{
			$permission->Load();
			if($permission->Result == PERMISSION_FULL)
			{
				$_user->AddFunctionCall("top.lz_chat_file_start_upload('".$_filename."');",false);
			}
			else
			{
				$_user->AddFunctionCall("top.lz_chat_file_stop();",false);
				$_user->AddFunctionCall("top.lz_chat_file_error(1);",false);
				$permission->Destroy();
				$request->Destroy();
			}
		}
		else if(!file_exists($request->TargetFile) && !file_exists($permission->TargetFile))
		{
			if(!isValidUploadFile($_filename))
			{
				$_user->AddFunctionCall("top.lz_chat_file_error(2);",false);
			}
			else
			{
				$files = getDirectory(PATH_DATA_INTERNAL . $this->DesiredChatPartner,false);
				foreach($files as $file)
				{
					if(strpos($file, "." . EX_FILE_UPLOAD_REQUEST) !== false && strpos($file, $this->BrowserId) !== false)
						@unlink(PATH_DATA_INTERNAL . $this->DesiredChatPartner . "/" . $file);
				}
				$request->Save();
			}
		}
		return $_user;
	}
	
	function AbortFileUpload($_user,$_filename,$_error)
	{
		$fileid = substr(md5(namebase($_filename)),0,5);
		$request = new FileUploadRequest($this->BrowserId . "_" . $fileid,$this->DesiredChatPartner);
		if(file_exists($request->TargetFile))
		{
			$request->Load();
			$request->Error = $_error;
			$request->Save();
		}
		
		$permission = new Permission("FileUploadPermission",$this->UserId,$this->BrowserId,$this->BrowserId . "_" . $fileid);
		if(file_exists($permission->TargetFile))
			$permission->Destroy();
	}
	
	function Load()
	{
		$fileEditor = new FileEditor($this->SessionFile);
		$fileEditor->Load();
		if(count($fileEditor->Errors) == 0)
		{
			if(isset($fileEditor->Result["s_fullname"]))
				$this->Fullname = $fileEditor->Result["s_fullname"];
			
			$this->Email = $fileEditor->Result["s_email"];
			$this->Company = $fileEditor->Result["s_company"];
			$this->Waiting = $fileEditor->Result["s_waiting"];
			$this->FirstActive = $fileEditor->Result["s_first_active"];
			$this->Typing = $fileEditor->Result["s_typing"];
			$this->Code = $fileEditor->Result["s_code"];
			$this->DesiredChatPartner = $fileEditor->Result["s_internal"];
			$this->DesiredChatGroup = $fileEditor->Result["s_group"];
			$this->WaitingMessageDisplayed = $fileEditor->Result["s_waiting_message"] ;
		}
		else
			$this->FileError = $fileEditor->Errors;
		$this->AppendFromCookies();
	}
	
	function LoadChat($_timeout,$_internal)
	{
		$this->Chat = null;
		$chatfiles = getDirectory($this->Folder,false);
		foreach($chatfiles as $chatfile)
			if(strpos($chatfile, "." . EX_CHAT_OPEN) !== false)
			{
				if($this->Chat == null)
				{
					$partnerid = str_replace("." . EX_CHAT_OPEN,"",$chatfile);
					if(strpos($chatfile, "." . EX_CHAT_OPEN) !== false)
					{
						$this->Chat = new Chat(null,null);
						$this->Chat->Load($this->Folder . $chatfile);
						
						if($this->Chat->FileError != null)
							$this->FileError = $this->Chat->FileError;
						
						if($_internal == null)
						{
							$_internal = new UserInternal($partnerid,null);
							$_internal->Load();
							$this->DesiredChatPartnerTyping = ($_internal->Typing == $this->SystemId);
						}
						
						if($_internal->FileError == null && ($_internal->Status == 2 || @filemtime($_internal->SessionFile) < (time()-$_timeout)))
						{
							$this->Chat->Closed = true;
						}
					}
				}
				else
					@unlink($this->Folder . $chatfile);
			}
	}
	
	function GetForwards()
	{
		$this->Forward = null;
		$actionfiles = getDirectory($this->Folder,false);
		sort($actionfiles);
		foreach($actionfiles as $index => $file)
		{
			if(strpos($file,EX_CHAT_FORWARDING) !== false)
			{
				if(isnull($this->Forward))
				{
					$this->Forward = new Forward($this->UserId,$this->BrowserId,str_replace("." . EX_CHAT_FORWARDING,"",$file));
					$this->Forward->Load();
				}
			}
		}
	}
	
	function CreateChat($_internalUser)
	{
		$this->DestroyChatFiles();
		$this->Chat = new Chat($this,$_internalUser);
		if(!file_exists($this->Chat->TargetFileExternalActivation))
		{
			$this->Chat->Save();
			return true;
		}
		return false;
	}
	
	function CreateComparer()
	{
		$this->Comparer = new ExternalChat($this->UserId,$this->BrowserId);
		$this->Comparer->Typing = $this->Typing;
		$this->Comparer->Fullname = $this->Fullname;
		$this->Comparer->Email = $this->Email;
		$this->Comparer->Company = $this->Company;
		$this->Comparer->Waiting = $this->Waiting;
		$this->Comparer->Code = $this->Code;
		$this->Comparer->FirstActive = $this->FirstActive;
		$this->Comparer->DesiredChatPartner = $this->DesiredChatPartner;
		$this->Comparer->DesiredChatGroup = $this->DesiredChatGroup;
		$this->Comparer->WaitingMessageDisplayed = $this->WaitingMessageDisplayed;
	}
	
	function EcoSave($difference = false)
	{
		if($this->Comparer->Typing != $this->Typing)$difference = true;
		else if($this->Comparer->Fullname != $this->Fullname)$difference = true;
		else if($this->Comparer->LastActive != $this->LastActive)$difference = true;
		else if($this->Comparer->Email != $this->Email)$difference = true;
		else if($this->Comparer->Company != $this->Company)$difference = true;
		else if($this->Comparer->Waiting != $this->Waiting)$difference = true;
		else if($this->Comparer->Code != $this->Code)$difference = true;
		else if($this->Comparer->FirstActive != $this->FirstActive)$difference = true;
		else if($this->Comparer->DesiredChatPartner != $this->DesiredChatPartner)$difference = true;
		else if($this->Comparer->DesiredChatGroup != $this->DesiredChatGroup)$difference = true;
		else if($this->Comparer->WaitingMessageDisplayed != $this->WaitingMessageDisplayed)$difference = true;

		if($difference || $this->NoEco)
			$this->Save();
		else
			$this->KeepAlive();
	}
	
	function SendChatTranscript($_config)
	{
		if($_config["gl_scct"] != null || $_config["gl_soct"] != null)
		{
			$file = PATH_CHAT_LOGS . date("m_d_y") . "_" . CALLER_TYPE_EXTERNAL . "_" . $this->DesiredChatPartner . "_" . $this->SystemId . ".log";
			$message = getFile($file);
			if(file_exists($file))
			{
				if($_config["gl_soct"])
					sendMail($this->Email,$_config["gl_mail_sender"],$_config["gl_mail_sender"],$message,$_config["gl_site_name"] . " Chat Transcript");
				if($_config["gl_scct"])
					sendMail($_config["gl_scct"],$_config["gl_mail_sender"],$_config["gl_mail_sender"],$message,$_config["gl_site_name"] . " Chat Transcript");
			}
		}
	}
	
	function DestroyChatFiles()
	{
		$chatfiles = getDirectory($this->Folder,false);
		foreach($chatfiles as $chatfile)
			if(strpos($chatfile, "." . EX_CHAT_OPEN) !== false || strpos($chatfile, "." . EX_CHAT_ACTIVE) !== false || strpos($chatfile, "." . EX_CHAT_INTERN_CLOSED) != false || strpos($chatfile, "." . EX_CHAT_INTERN_DECLINED) != false)
				@unlink($this->Folder . $chatfile);
	}
	
	function Destroy($_config)
	{
		if(file_exists($this->SessionFile))
		{
			deleteDirectory($this->Folder);
			$this->SendChatTranscript($_config);
		}
	}
}

class ExternalStatic extends User
{
	var $SystemInfo;
	var $Language;
	var $Resolution;
	
	var $Name;
	var $Email;
	var $Company;
	var $Visits = 1;
	var $GeoCity;
	var $GeoCountryISO2;
	var $GeoRegion;
	var $GeoLongitude= -522;
	var $GeoLatitude= -522;
	var $GeoTimezoneOffset = "+00:00";
	
	function ExternalStatic($_userid)
   	{
		$this->UserId = $_userid;
		$this->Folder = PATH_DATA_EXTERNAL . $this->UserId . "/";
		$this->SessionFile = $this->Folder . $this->UserId . "." . EX_STATIC_INFO;
   	}
	
	function Load()
	{
		$fileEditor = new FileEditor($this->SessionFile);
		$fileEditor->Load();
		
		if(count($fileEditor->Errors) == 0)
		{
			$this->IP = $fileEditor->Result["s_ip"];
			$this->SystemInfo = $fileEditor->Result["s_system"];
			$this->Language = $fileEditor->Result["s_language"];
			$this->Resolution = $fileEditor->Result["s_resolution"];
			
			if(isset($fileEditor->Result["s_geotz"]))
				$this->GeoTimezoneOffset = $fileEditor->Result["s_geotz"];
			if(isset($fileEditor->Result["s_geolong"]))
				$this->GeoLongitude = $fileEditor->Result["s_geolong"];
			if(isset($fileEditor->Result["s_geolat"]))
				$this->GeoLatitude = $fileEditor->Result["s_geolat"];
			if(isset($fileEditor->Result["s_geocity"]))
				$this->GeoCity = $fileEditor->Result["s_geocity"];
			if(isset($fileEditor->Result["s_geocountry"]))
				$this->GeoCountryISO2 = $fileEditor->Result["s_geocountry"];
			if(isset($fileEditor->Result["s_georegion"]))
				$this->GeoRegion = $fileEditor->Result["s_georegion"];
			if(isset($fileEditor->Result["s_visits"]))
				$this->Visits =	$fileEditor->Result["s_visits"];
		}
		else
		{
			$this->FileError = $fileEditor->Errors;
		}
	}
	
	function GetData()
	{
		$data = Array();
		$data["s_ip"] = $this->IP;
		$data["s_system"] = $this->SystemInfo;
		$data["s_language"] = $this->Language;
		$data["s_resolution"] = $this->Resolution;
		$data["s_geotz"] = $this->GeoTimezoneOffset;
		if(is_numeric($this->GeoLongitude))
			$data["s_geolong"] = $this->GeoLongitude;
		if(is_numeric($this->GeoLatitude))
			$data["s_geolat"] = $this->GeoLatitude;
		$data["s_geocity"] = $this->GeoCity;
		$data["s_geocountry"] = $this->GeoCountryISO2;
		$data["s_georegion"] = $this->GeoRegion;
		$data["s_visits"] = $this->Visits;
		return $data;
	}
}
?>